Skip to contents

Count how many times an enzyme is involved in the biosynthesis of a glycan.

Usage

count_enzyme(glycans, enzyme, method = c("motif", "path"))

Arguments

glycans

A glyrepr::glycan_structure(), or a character vector of glycan structure strings supported by glyparse::auto_parse().

enzyme

An enzyme() or a gene symbol.

method

Method used to count enzyme involvement. "motif" counts product motifs directly in each glycan. "path" counts enzyme-labeled edges in trace_biosynthesis() results, which is more accurate but slower.

Value

An integer vector of the same length as glycans.

Important notes

Here are some important notes for all functions in the glyenzy package.

Applicability

Known-enzyme algorithms and enzyme information in glyenzy are applicable only to humans. Curated coverage is strongest for N-glycans and O-glycans and also includes selected glycosphingolipid headgroups and other glycan contexts. Lipid and protein aglycones are not represented, so glycolipid rules model the carbohydrate headgroup with ceramide omitted. Results may be inaccurate for unsupported glycan contexts or other species (e.g., plants, insects).

Inclusiveness

The algorithm takes an intentionally inclusive approach, assuming that all possible isoenzymes capable of catalyzing a given reaction may be involved. Therefore, results should be interpreted with caution.

For example, in humans, detection of the motif "Neu5Ac(a2-3)Gal(b1-" will return both "ST3GAL3" and "ST3GAL4". In reality, only one of them might be active, depending on factors such as tissue specificity.

Concrete glycans by default

Most functions only work for glycans containing concrete residues (e.g., "Glc", "GalNAc"), and not for glycans with generic residues (e.g., "Hex", "HexNAc"). Inputs with generic or mixed residues are supported where explicitly documented, such as trace_biosynthesis() and path_biosynthesis().

Substituents

Sulfate substituents are supported. Other substituents, such as phosphorylation and methylation, are not supported. Use glyrepr::remove_substituents() when unsupported substituents are present.

Incomplete or non-concrete glycan structures

If the glycan structure is incomplete, partially degraded, or contains generic or mixed residues, the result may be misleading. Glycans with a glyrepr::get_structure_level() other than "intact", or with a glyrepr::get_mono_type() other than "concrete", are matched with the lenient motif matching mode in glymotif. A warning is raised because enzyme predictions may be less reliable.

Starting points

For known-enzyme path inference:

  • For N-glycans, the starting structure is assumed to be "Glc(3)Man(9)GlcNAc(2)", the N-glycan precursor transferred to Asn by OST.

  • For O-GalNAc glycans, the starting structure is assumed to be "GalNAc(a1-".

  • For O-GlcNAc glycans, the starting structure is assumed to be "GlcNAc(b1-".

  • For O-Man glycans, the starting structure is assumed to be "Man(a1-".

  • For O-Fuc glycans, the starting structure is assumed to be "Fuc(a1-".

  • For O-Glc glycans, the starting structure is assumed to be "Glc(b1-".

  • For GlcCer glycans, the starting structure is assumed to be "Glc(b1-",

  • For GalCer glycans, the starting structure is assumed to be "Gal(b1-"

Examples

library(glyrepr)
library(glyparse)

# Use `glycan_structure()` and `enzyme()`
glycan <- auto_parse("Neu5Ac(a2-6)Gal(b1-4)GlcNAc(b1-")
count_enzyme(glycan, enzyme("ST6GAL1"))
#> [1] 1

# Or use characters directly
count_enzyme("Neu5Ac(a2-6)Gal(b1-4)GlcNAc(b1-", "ST6GAL1")
#> [1] 1

# Vectorized input
glycans <- c(
  "Neu5Ac(a2-6)Gal(b1-4)GlcNAc(b1-",
  "Gal(b1-4)GlcNAc(b1-"
)
count_enzyme(glycans, "ST6GAL1")
#> [1] 1 0

# Use reconstructed biosynthesis paths
count_enzyme(glycans, "ST6GAL1", method = "path")
#> [1] 1 0