Skip to contents

Two types of enzymes are involved in glycosylation: glycosyltransferases (GTs) and glycoside hydrolases (GHs).

  • GTs catalyze the transfer of a sugar residue from a donor to an acceptor, thus building up glycan structures.

  • GHs catalyze the removal of a sugar residue from a substrate, thus breaking down glycan structures.

One special subtype of GTs are starter GTs (or initiating GTs), which catalyze the addition of the first sugar residue onto a non-glycan substrate, thus initiating glycosylation.

Use enzyme() with a gene symbol to load a predefined enzyme. For example, use enzyme("ST3GAL3") to load the enzyme ST3GAL3.

Throughout the package, you can use enzyme()s for any enzyme argument, or just use the gene symbol directly. For example, involve("Neu5Ac(a2-3)Gal(b1-3)GalNAc(a1-", "ST3GAL3") and involve("Neu5Ac(a2-3)Gal(b1-3)GalNAc(a1-", enzyme("ST3GAL3")) are equivalent.

Usage

enzyme(symbol)

Arguments

symbol

The gene symbol of the enzyme.

Value

A glyenzy_enzyme object.

Explanation about glyenzy_enzyme

An enzyme() is a list with the following elements:

  1. name: the name of the enzyme, usually the gene symbol.

  2. rules: a list of glyenzy_enzyme_rule objects. Each rule is a list with the following fields:

    • acceptor: the motif that the enzyme recognizes

    • acceptor_alignment: the alignment of the acceptor

    • rejects: the motifs that the enzyme rejects to act on

    • product: the product generated by the enzyme

    • acceptor_idx: the node index of the acceptor where the enzyme acts on. For GTs, this is the node new residue is attached to. For GHs, this is the node that is removed. For starter GTs, acceptor_idx is 0.

    • product_idx: the node index of the product residue in the product structure. For GTs, this is the index of the newly added residue in the product. For GHs, this is NULL (no new residue is added).

    • new_residue: the new residue added by the enzyme. For GHs, this is NULL.

    • new_linkage: the linkage of the new residue. For GHs, this is NULL.

  3. type: the broad type of the enzyme, "GT" for glycosyltransferase or "GH" for glycoside hydrolase. Starter GTs are encoded as type = "GT".

  4. species: the species of the enzyme, e.g. "human" or "mouse".

You can see all these information by printing the enzyme object.

Examples

library(glyrepr)

enzyme("ST3GAL3")
#> 
#> ── Enzyme: ST3GAL3 ─────────────────────────────────────────────────────────────
#>  Type: "GT" (Glycosyltransferase)
#>  Species: "human"
#> 
#> ── Rules (2) ──
#> 
#> → Rule 1: terminal alignment
#> Acceptor: "Gal(b1-3)GlcNAc(b1-"
#> Product: "Neu5Ac(a2-3)Gal(b1-3)GlcNAc(b1-"
#> Rejects:
#> "Gal(b1-3)[Fuc(a1-4)]GlcNAc(b1-"
#> → Rule 2: terminal alignment
#> Acceptor: "Gal(b1-4)GlcNAc(b1-"
#> Product: "Neu5Ac(a2-3)Gal(b1-4)GlcNAc(b1-"
#> Rejects:
#> "Fuc(a1-3)[Gal(b1-4)]GlcNAc(b1-"